#
# spec file for package python-buku
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-buku
Version:        3.7
Release:        lp152.3.2
Summary:        Command-line bookmark manager
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
Url:            https://github.com/jarun/Buku
Source0:        https://files.pythonhosted.org/packages/source/b/buku/buku-%{version}.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module setuptools}
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  python-rpm-macros
BuildRequires:  zsh
Requires:       python-base
Requires:       python-beautifulsoup4 >= 4.4.1
Requires:       python-cryptography >= 1.2.3
Requires:       python-requests >= 2.9.1
Requires:       python-urllib3 >= 1.13.1
Requires:       sqlite3
Recommends:     xsel
BuildArch:      noarch
Provides:       Buku == %{version}
Obsoletes:      Buku < %{version}
%python_subpackages

%description
Bookmark management utility written in Python3 and SQLite3.

With tagging and multiple options to search bookmarks, including
regex and a deep scan mode (particularly for URLs), finding a
bookmark is very easy. Multiple search results can be opened in
the browser at once.

Though a terminal utility, it's possible to add bookmarks to buku
without touching the terminal.
Buku supports revisiting random forgotten bookmarks too.

%package        bash-completion
Summary:        Bash completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Supplements:    packageand(%{name}:bash)
Requires:       bash-completion
BuildArch:      noarch

%description    bash-completion
Bash command line completion support for %{name}.

%package        fish-completion
Summary:        Fish completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Supplements:    packageand(%{name}:fish)
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command line completion support for %{name}.

%package        zsh-completion
Summary:        ZSH Completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Supplements:    packageand(%{name}:zsh)
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for %{name}.

%prep
%setup -q -n buku-%{version}
# remove shebang
sed -e '1d' -i buku.py

%build
%python_build

%install
%python_install
mkdir -pv %{buildroot}%{_mandir}/man1 %{buildroot}%{_datadir}/bash-completion/completions \
          %{buildroot}%{_datadir}/fish/completions %{buildroot}%{_datadir}/zsh/site-functions
install -m0644 buku.1 -t %{buildroot}%{_mandir}/man1
install -m0644 auto-completion/bash/buku-completion.bash -t %{buildroot}%{_datadir}/bash-completion/completions
install -m0644 auto-completion/fish/buku.fish -t %{buildroot}%{_datadir}/fish/completions
install -m0644 auto-completion/zsh/_buku -t %{buildroot}%{_datadir}/zsh/site-functions

%files %{python_files}
%doc CHANGELOG README.md
%license LICENSE
%python3_only %{_bindir}/buku
%python3_only %{_mandir}/man1/buku.1%{ext_man}
%{python_sitelib}/*

%files %{python_files bash-completion}
%{_datadir}/bash-completion/completions/buku-completion.bash

%files %{python_files fish-completion}
%{_datadir}/fish/completions/buku.fish

%files %{python_files zsh-completion}
%{_datadir}/zsh/site-functions/_buku

%changelog
* Wed Mar 28 2018 aloisio@gmx.com
- Update to version 3.7
  * Exclude keywords in search (keyword filtering)
  * Search and filter by tags
  * Order search results by number of keyword matches
  * Copy URL to clipboard
  * Prompt shortcut 'O' to override text browsers
  version 3.6
  * Skip bookmark addition if edit is aborted
  * Use urllib3 for handling http connections everywhere
* Fri Nov 10 2017 aloisio@gmx.com
- Update to version 3.5
  * Buku now has its own user agent
  * Search works with field filters
  * Edit the last record with -w=-1 (useful when adding bookmark
    from GUI)
  * Support for Chromium browser
  * Get default Firefox profile name from profiles.ini
  * Bash scriptlet to autogen records for testing
  * Some optimization in add record and suggest tags
  * A fresh utility Pinku to import Pinboard bookmarks to Buku
* Mon Sep 18 2017 aloisio@gmx.com
- Update to version 3.4
  * Export bookmarks (including specific tags) to Buku DB file
    using --export
  * Option --import can merge Buku DB files now, option --merge is
    retired
  * Option --suggest now works at prompt as well
  * Auto-import issue when Firefox is not installed fixed
* Mon Sep 11 2017 aloisio@gmx.com
- Update to version 3.3.1
  * Auto-import (--ai) bookmarks from Firefox and Google Chrome
  * Support custom colors (--colors)
  * Search multiple tags (with exclusion)
  * Timestamp (YYYYMonDD) tag in auto-imported bookmarks
  * Enable browser output for text browsers
  * Generate documentation in RTD using Sphinx
    (http://buku.readthedocs.io)
  * Integrated flake8 and pylint in Travis CI
  * Integrated PackageCore to auto-generate packages in Travis CI
* Thu Aug  3 2017 aloisio@gmx.com
- Update to version 3.2
  * Option `--suggest` to list and choose similar tags when
    adding a bookmark
  * Ask for a unique tag when importing bookmarks
  * Ignore non-generic URLs when importing browser exported
    bookmarks
* Tue Jul 11 2017 aloisio@gmx.com
- Update to version 3.1
  * Handle negative indices (like tail) with option -p
  * Support browsing bookmarks from prompt (key o)
  * Add program search keywords to history
  * Support XDG_DATA_HOME and HOME as env vars on all platforms
* Thu Jun 29 2017 aloisio@gmx.com
- Update to version 3.0
  * Edit bookmarks in EDITOR at prompt
  * Import folder names as tags from browser html (thanks
    @mohammadKhalifa)
  * Append, overwrite, delete tags at prompt using >>, >, <<
    (familiar, eh? ;))
  * Negative indices with `--print` (like `tail`)
  * Update in EDITOR along with `--immutable`
  * Request HTTP HEAD for immutable records
  * Interface revamp (title on top in bold, colour changes...)
  * Per-level colourful logs in colour mode
  * Changes in program OPTIONS
    + `-t` stands for tag search (earlier `--title`)
    + `-r` stands for regex search (earlier `--replace`)
  * Lots of new automated test cases (thanks @rachmadaniHaryono)
  * REST APIs for server-side apps (thanks @kishore-narendran)
  * Document, notify behaviour when not invoked from tty (thanks
    @The-Compiler)
  * Fix Firefox tab-opening issues on Windows (thanks
    @dertuxmalwieder)
- Renamed package to python-buku
- Converted to single-spec
* Sat Mar  4 2017 jengelh@inai.de
- Ensure NPOV of description
* Thu Feb 23 2017 aloisio@gmx.com
- Update to version 2.9
  * New option `-write` to compose and edit bookmarks in text
    editor
  * Support positional arguments as search keywords
  * New option `--oa` to search and open results directly in
    browser
  * Autodetect Markdown mode by file extension during export,
    import
  * Shortened options:
    + `--nc` replaces `--nocolor`
    + `--np` replaces `--noprompt`
    + `-V` replaces `--upstream`
  * Option `--markdown` removed as the mode is autodetected now
  version 2.8
  * Multithreaded full DB refresh with delayed writes
  * Customize number of threads for full DB refresh (default 4)
  * Support search and update search results in a go
  * Support shortened URL expansion
  * Support multiple bookmarks with `--open`
  * Support `--nocolor` (for scripting, Windows users)
  * Support https_proxy with `--upstream` and `--shorten`
  * Remove trailing `/` from search tokens (like Google search)
  * Support `--version` to show program version
  * Fixed #109: Missing + when shortening URL
  * Performance optimizations, few module dependency removals
  version 2.7
  * Continuous search at (redesigned) prompt
  * urllib3 for all HTTP operations
  * Use HTTP HEAD method for pdf and txt mime types
  * Add user agent (Firefox 50 on Ubuntu)
  * Support URL shortening
  * List bookmarks by tag index in tag list
  * Show tag usage count in tag list
  * Store tags in lowercase (use undocumented option
    `--fixtags` to fix old tags)
  * Support environment variable *https_proxy*
  * Support option `--immutable` to pin titles
  * Keyword `immutable` to search (`-S`) pinned titles
  * Show index in Json output
  * New key *q* to quit prompt
  * Support deflate compression
  * Add option `--tacit` to reduce verbosity of some operations
  * **Removed** option `--st`, only `--stag` to search tags
  * Support custom DB file location (for library, not exposed
    to user)
* Sat Nov  5 2016 aloisio@gmx.com
- Initial package (version 2.6)
